@@ -1,4 +1,5 @@
 import logging
+from pathlib import Path
 from typing import Any, Mapping, Optional
 
 from pydantic import BaseSettings, PostgresDsn, validator
@@ -15,6 +16,7 @@ class Settings(BaseSettings):
     use_x_forwarded_proto: bool = False
 
     postgres_dsn: PostgresDsn
+    postgres_engine_options: dict = {"connect_args": {"application_name": "api-reflector"}}
 
     log_json: bool = True
     log_level: str = "info"
@@ -23,6 +25,11 @@ class Settings(BaseSettings):
 
     trace_query_descriptions: bool = False
 
+    # in seconds. delays will not last longer than this.
+    maximum_delay_length: Optional[float] = None
+
+    lockfile_path: Path = Path("/tmp/.api-reflector.lock")
+
     @validator("azure_client_id", "azure_client_secret", "azure_tenant")
     @classmethod
     def enabled_auth_settings(cls, v: Optional[str], values: Mapping[str, Any]) -> Optional[str]:
